Chromaprint for Python
===================================

This is a re-packaged version of `pyacoustid`_ that includes only
the low-level bindings for the Chromaprint library. See the original
project for more details. In most cases, you do not need this
package and should use the original. This is needed for deployment
of the AcoustID server, because of the "acoustid" package name clash.

.. _pyacoustid: https://github.com/sampsyo/pyacoustid
